@@ -5,7 +5,7 @@ import os
 from datetime import datetime, timedelta
 from random import randint
 from pathlib import Path
-import OS
+from . import OS
 
 
 def now_dt_str():
